package be.bitscuit.calendar.Activities;

import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.widget.Toolbar;
import androidx.fragment.app.DialogFragment;
import androidx.recyclerview.widget.DividerItemDecoration;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import android.app.DatePickerDialog;
import android.app.Dialog;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.DatePicker;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import java.util.Calendar;

import be.bitscuit.calendar.Util.ListAdapter;
import be.bitscuit.calendar.R;
import be.bitscuit.calendar.Util.TaskData;
import be.bitscuit.calendar.Util.TaskUtil;
import be.bitscuit.calendar.Util.Util;

public class MainActivity extends AppCompatActivity
        implements DatePickerDialog.OnDateSetListener{

    private TaskUtil taskUtil;
    private TaskData[] taskData;

    private RecyclerView listView;
    private RecyclerView.LayoutManager layoutManager;
    private ListAdapter listAdapter;

    private Toolbar toolbar;
    private TextView emptyText;
    private ImageView imageNext, imageBack;

    private long showDateMillis = Util.millisToDateMillis(System.currentTimeMillis());

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        //Set toolbar
        toolbar = findViewById(R.id.main_toolbar);
        setSupportActionBar(toolbar);
        setTitle(Util.formatMillis(System.currentTimeMillis(), "E dd/MM/yyyy"));

        //Load data
        taskUtil = new TaskUtil(this);
        taskData = new TaskData[0];

        //Set views
        emptyText = findViewById(R.id.main_text_empty);
        imageNext = findViewById(R.id.main_image_next);
        imageBack = findViewById(R.id.main_image_back);

        //Edit view properties
        imageNext.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Calendar calendar = Calendar.getInstance();
                calendar.setTimeInMillis(showDateMillis);
                calendar.add(Calendar.DATE, 1);
                showDateMillis = calendar.getTimeInMillis();
                updateList();
            }
        });
        imageBack.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Calendar calendar = Calendar.getInstance();
                calendar.setTimeInMillis(showDateMillis);
                calendar.add(Calendar.DATE, -1);
                showDateMillis = calendar.getTimeInMillis();
                updateList();
            }
        });

        //Set list
        listView = findViewById(R.id.main_list);
        listView.addItemDecoration(new DividerItemDecoration(listView.getContext(), DividerItemDecoration.VERTICAL));
        layoutManager = new LinearLayoutManager(this);
        listView.setLayoutManager(layoutManager);
        listAdapter = new ListAdapter(taskData);
        listView.setAdapter(listAdapter);

        listAdapter.setOnTaskClickListener(new ListAdapter.OnTaskClickListener() {
            @Override
            public void onClick(View view, int taskID) {
                //Open edit activity
                Intent intent = new Intent(view.getContext(), EditActivity.class);
                intent.putExtra("TASK_ID", taskID);
                startActivity(intent);
            }
        });
    }



    public void updateList(){
        //Update list
        taskData = taskUtil.getTaskDataForDate(showDateMillis);
        listAdapter.changeData(taskData);

        //Show emptyText if no data and vice versa
        if(taskData.length == 0){
            emptyText.setVisibility(View.VISIBLE);
            listView.setVisibility(View.GONE);
        }else {
            emptyText.setVisibility(View.GONE);
            listView.setVisibility(View.VISIBLE);
        }

        //Update title
        setTitle(Util.formatMillis(showDateMillis, "E dd/MM/yyyy"));

        System.out.println("List updated");
    }


    @Override
    public boolean onCreateOptionsMenu(final Menu menu) {
        getMenuInflater().inflate(R.menu.menu_main, menu);

        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.main_menu_settings:
                Intent intent = new Intent(this, SettingsActivity.class);
                startActivity(intent);
                return true;

            case R.id.main_menu_date:
                //Show date picker
                DialogFragment fragment = new DatePickerFragment(this);
                fragment.show(getSupportFragmentManager(), "datePicker");
                return true;

            case R.id.main_menu_add_task:
                //Open edit activity, and pass millis from currently viewing date
                Calendar calendar = Calendar.getInstance();
                calendar.setTimeInMillis(showDateMillis);
                int y = calendar.get(Calendar.YEAR);
                int m = calendar.get(Calendar.MONTH);
                int d = calendar.get(Calendar.DAY_OF_MONTH);
                calendar.clear();
                calendar.setTimeInMillis(System.currentTimeMillis());
                calendar.set(y, m, d, calendar.get(Calendar.HOUR_OF_DAY), calendar.get(Calendar.MINUTE));
                long millis = calendar.getTimeInMillis();

                intent = new Intent(this, EditActivity.class);
                intent.putExtra("TASK_TIME_START", millis);
                startActivity(intent);
                return true;

            default:
                // Action not recognized -> let superclass handle it
                return super.onOptionsItemSelected(item);

        }
    }


    public static class DatePickerFragment extends DialogFragment {

        private MainActivity mainActivity;

        public DatePickerFragment(MainActivity mainActivity){
            this.mainActivity = mainActivity;
        }

        @Override
        public Dialog onCreateDialog(Bundle savedInstanceState) {
            // Use the shown date as the default date in the picker
            final Calendar c = Calendar.getInstance();
            c.setTimeInMillis(mainActivity.showDateMillis);
            int year = c.get(Calendar.YEAR);
            int month = c.get(Calendar.MONTH);
            int day = c.get(Calendar.DAY_OF_MONTH);

            // Create a new instance of DatePickerDialog and return it
            return new DatePickerDialog(getActivity(), mainActivity, year, month, day);
        }
    }



    public void onDateSet(DatePicker view, int year, int month, int day) {
        // Do something with the date chosen by the user
        Calendar calendar = Calendar.getInstance();
        calendar.set(Calendar.YEAR, year);
        calendar.set(Calendar.MONTH, month);
        calendar.set(Calendar.DAY_OF_MONTH, day);
        long millis = calendar.getTimeInMillis();

        //Change list data
        showDateMillis = Util.millisToDateMillis(millis);

        updateList();
    }


    @Override
    protected void onResume() {

        //Update list
        taskUtil.reload();
        updateList();

        super.onResume();
    }
}
