package be.bitscuit.calendar.BroadcastReceivers;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.media.RingtoneManager;
import android.os.Build;

import androidx.core.app.NotificationCompat;
import androidx.core.app.NotificationManagerCompat;

import be.bitscuit.calendar.Activities.MainActivity;
import be.bitscuit.calendar.R;
import be.bitscuit.calendar.Util.TaskData;
import be.bitscuit.calendar.Util.TaskUtil;
import be.bitscuit.calendar.Util.Util;

public class AlarmReceiver extends BroadcastReceiver {

    private final static String CHANNEL_ID = "be.bitscuit.calendar.NOTIFICATIONS_REMINDER";

    @Override
    public void onReceive(Context context, Intent intent) {

        int taskID = intent.getIntExtra("TASK_ID", 0);
        if(taskID == 0) return;//Something went wrong while setting the alarm

        TaskUtil taskUtil = new TaskUtil(context);
        TaskData taskData = taskUtil.getByTaskID(taskID);
        if(taskData == null) return;//Task doesn't exist


        // Create the NotificationChannel, but only on API 26+
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            String name = "Appointment Reminders";
            String description = "Receive reminders for important appointments.";
            int importance = NotificationManager.IMPORTANCE_HIGH;
            NotificationChannel channel = new NotificationChannel(CHANNEL_ID, name, importance);
            channel.setDescription(description);

            NotificationManager notificationManager = context.getSystemService(NotificationManager.class);
            notificationManager.createNotificationChannel(channel);
        }


        //Create notification
        Intent i = new Intent(context, MainActivity.class);
        intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, i, 0);

        NotificationCompat.Builder builder = new NotificationCompat.Builder(context, CHANNEL_ID)
                .setSmallIcon(R.drawable.ic_alarm)
                .setContentTitle(taskData.getTitle())
                .setContentText("at "+ Util.formatMillis(taskData.getTimeStart(), "HH:mm"))
                .setPriority(NotificationCompat.PRIORITY_HIGH)
                .setContentIntent(pendingIntent)
                .setAutoCancel(true)
                .setVibrate(new long[]{0, 250, 250, 250, 250, 250, 250})
                .setLights(Color.RED, 500, 1500)
                .setSound(RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION));


        NotificationManagerCompat nmc = NotificationManagerCompat.from(context);
        nmc.notify(taskData.getTaskID(), builder.build());


    }
}
