package be.bitscuit.calendar.BroadcastReceivers;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.media.RingtoneManager;
import android.os.Build;
import android.widget.Toast;

import androidx.core.app.NotificationCompat;
import androidx.core.app.NotificationManagerCompat;

import be.bitscuit.calendar.Activities.MainActivity;
import be.bitscuit.calendar.R;
import be.bitscuit.calendar.Util.TaskData;
import be.bitscuit.calendar.Util.TaskUtil;
import be.bitscuit.calendar.Util.Util;

public class OverviewReceiver extends BroadcastReceiver {

    private final static String CHANNEL_ID = "be.bitscuit.calendar.NOTIFICATIONS_OVERVIEW";

    @Override
    public void onReceive(Context context, Intent intent) {

        //Load tasks
        TaskUtil taskUtil = new TaskUtil(context);
        TaskData[] tasks = taskUtil.getTaskDataForDate(Util.millisToDateMillis(System.currentTimeMillis()));

        //Create notification text
        String text = "";
        for(int i=0; i<tasks.length; i++){
            text += Util.formatMillis(tasks[i].getTimeStart(), "HH:mm") + " - " + Util.formatMillis(tasks[i].getTimeEnd(), "HH:mm");
            text += " -> " + tasks[i].getTitle();
            text += i != tasks.length-1?"\n":"";
        }
        if(text.equals("")) text = "No Appointments";



        // Create the NotificationChannel, but only on API 26+
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            String name = "Daily Appointment Overview";
            String description = "Receive a daily notification with the appointments of that day.";
            int importance = NotificationManager.IMPORTANCE_HIGH;
            NotificationChannel channel = new NotificationChannel(CHANNEL_ID, name, importance);
            channel.setDescription(description);

            NotificationManager notificationManager = context.getSystemService(NotificationManager.class);
            notificationManager.createNotificationChannel(channel);
        }


        //Create notification
        Intent i = new Intent(context, MainActivity.class);
        intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, i, 0);

        NotificationCompat.Builder builder = new NotificationCompat.Builder(context, CHANNEL_ID)
                .setSmallIcon(R.drawable.ic_calendar_2)
                .setContentTitle("Today's Overview")
                .setContentText(text)
                .setStyle(new NotificationCompat.BigTextStyle()
                        .bigText(text))
                .setPriority(NotificationCompat.PRIORITY_HIGH)
                .setContentIntent(pendingIntent)
                .setAutoCancel(true)
                .setSound(RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION));


        NotificationManagerCompat nmc = NotificationManagerCompat.from(context);
        nmc.notify(999, builder.build());

    }
}
