package be.bitscuit.calendar.Util;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.recyclerview.widget.RecyclerView;

import be.bitscuit.calendar.R;

public class ListAdapter extends RecyclerView.Adapter<ListAdapter.ViewHolder> {

    private TaskData[] taskData;
    private OnTaskClickListener onTaskClickListener;

    public ListAdapter(TaskData[] data){
        this.taskData = data;
    }

    public void changeData(TaskData[] data){
        this.taskData = data;
        notifyDataSetChanged();
    }

    public void setOnTaskClickListener(OnTaskClickListener listener){
        onTaskClickListener = listener;
    }



    @NonNull
    @Override
    public ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        //Create a new ViewHolder
        View view = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.list_item, parent, false);

        ViewHolder holder = new ViewHolder(view);
        return holder;
    }

    @Override
    public void onBindViewHolder(@NonNull ViewHolder holder, int position) {
        //Set data of viewHolder
        TaskData data = taskData[position];
        holder.titleText.setText(data.getTitle());
        holder.timeText.setText(Util.formatMillis(data.getTimeStart(), "HH:mm") + " - "+ Util.formatMillis(data.getTimeEnd(), "HH:mm"));

        final int taskID = data.getTaskID();
        holder.layout.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                onTaskClickListener.onClick(view, taskID);
            }
        });
    }

    @Override
    public int getItemCount() {
        return taskData.length;
    }


    public static class ViewHolder extends RecyclerView.ViewHolder{

        public TextView titleText, timeText;
        public ConstraintLayout layout;

        public ViewHolder(View view){
            super(view);

            layout = view.findViewById(R.id.list_item_layout);
            titleText = view.findViewById(R.id.list_item_text_title);
            timeText = view.findViewById(R.id.list_item_text_time);
        }
    }


    public interface OnTaskClickListener{
        void onClick(View view, int taskID);
    }
}
